@@ -3,7 +3,7 @@ pub use cmd::{
     set_commit_authors::set_commit_authors,
     set_config_authors::set_config_authors,
 };
-pub use lib::{author::Author, authors::Authors};
+pub use lib::{author::Author, author_state::AuthorState, authors::Authors};
 
 pub mod cmd;
 pub mod lib;
